flash: Rename erase_flash to flash_erase

Change-Id: I417319aadb2fdbfa2d688bb26b5515d2f9265994
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/flash.c b/flash.c
index 811a25c..0f0b6b5 100644
--- a/flash.c
+++ b/flash.c
@@ -149,14 +149,14 @@
 }
 
 /*
  * erase_flash() - Erase the flash
  * @context:	The mbox context pointer
  * @offset:	The flash offset to erase (bytes)
  * @size:	The number of bytes to erase
  *
  * Return:	0 on success otherwise negative error code
  */
-int erase_flash(struct mbox_context *context, uint32_t offset, uint32_t count)
+int flash_erase(struct mbox_context *context, uint32_t offset, uint32_t count)
 {
 	const uint32_t erase_size = 1 << context->erase_size_shift;
 	struct erase_info_user erase_info = { 0 };
@@ -149,14 +149,14 @@
 
 /*
- * erase_flash() - Erase the flash
+ * flash_erase() - Erase the flash
  * @context:	The mbox context pointer
  * @offset:	The flash offset to erase (bytes)